// 判断传入时间是否是今天
export const isToday = (date) => {
	const today = new Date();
	const startOfDay = new Date(today.getFullYear(), today.getMonth(), today.getDate());
	const endOfDay = new Date(today.getFullYear(), today.getMonth(), today.getDate() + 1, 0, 0, 0, -1);
	return new Date(date) >= startOfDay &&  new Date(date) <= endOfDay;
};

// 判断传入的时间间隔是否小于30分
export function isWithinThirtyMinutes(time1, time2) {
	// 定义一个辅助函数来解析时间字符串为 Date 对象  
	function parseTime(timeStr) {
		const [dateStr, timeStrPart] = timeStr.split(' ');
		const [year, month, day] = dateStr.split('-').map(Number);
		const [hours, minutes] = timeStrPart.split(':').map(Number);
		return new Date(year, month - 1, day, hours, minutes); // 注意月份是从0开始的  
	}

	// 解析输入的时间字符串  
	const date1 = parseTime(time1);
	const date2 = parseTime(time2);

	// 计算时间差（毫秒）  
	const timeDifference = Math.abs(date2.getTime() - date1.getTime());


	// 将时间差转换为分钟并检查是否小于三小时 
	return timeDifference <= (180 * 60 * 1000); // 30分钟 * 60秒/分钟 * 1000毫秒/秒  
};
export function isWithin24Hours(time1, time2) {  
	function parseTime(timeStr) {
		const [dateStr, timeStrPart] = timeStr.split(' ');
		const [year, month, day] = dateStr.split('-').map(Number);
		const [hours, minutes] = timeStrPart.split(':').map(Number);
		return new Date(year, month - 1, day, hours, minutes); // 注意月份是从0开始的  
	}
    const date1 = parseTime(time1);  
    const date2 = parseTime(time2);  
      
    // 计算时间差（毫秒）  
    const timeDifference = Math.abs(date2.getTime() - date1.getTime());

      
    // 将时间差转换为小时  
    const hoursDifference = timeDifference / (1000 * 60 * 60);  
      
    // 检查是否小于或等于24小时  
    return hoursDifference <= 24;  
} 


// 获取指定时间之前的时间戳
export function getTimeStamp(type) {
	const now = new Date();
	let timestamp;

	switch (type) {
		case 0:
			// 获取当前时间的时间戳  
			timestamp = Math.floor(now.getTime() );
			break;
		case 1:
			// 获取30分钟之前的时间戳  
			now.setMinutes(now.getMinutes() - 180);
			timestamp = Math.floor(now.getTime());
			break;
		case 2:
			// 获取24小时之前的整点时间戳  
			now.setHours(now.getHours() - 24, 0, 0, 0);
			timestamp = Math.floor(now.getTime());
			break;
		case 3:
			// 获取48小时之前的整点时间戳  
			now.setHours(now.getHours() - 48, 0, 0, 0);
			timestamp = Math.floor(now.getTime() );
			break;
		case 4:
			// 获取现在的整点时间戳  
			now.setMinutes(0, 0, 0);
			timestamp = Math.floor(now.getTime());
			break;
		case 5:
			// 获取30天之前的整点时间戳  
			now.setDate(now.getDate() - 30);
			timestamp = Math.floor(now.getTime());
			break;
		default:
			throw new Error('Invalid type');
	}

	return timestamp;
}

// 获取传入时间秒的时间戳
export function getStamp(time) {
	const date = new Date(time);
	return Math.floor(date.getTime() / 1000);
}


